@@ -8,6 +8,7 @@
 #include "language.h"
 #include "message.h"
 #include "dot.h"
+#include "layout.h"
 
 //----------------------------------------------------------------------
 // method implementation
@@ -107,25 +108,37 @@ QCString DirDef::getOutputFileBase() const
   //return QCString().sprintf("dir_%06d",m_dirCount);
 }
 
-void DirDef::writeDetailedDocumentation(OutputList &ol)
+void DirDef::writeDetailedDescription(OutputList &ol,const QCString &title)
 {
-  if (!briefDescription().isEmpty() || !documentation().isEmpty())
+  if ((!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF")) || 
+      !documentation().isEmpty())
   {
     ol.writeRuler();
     ol.pushGeneratorState();
-      ol.disable(OutputGenerator::Latex);
-      ol.disable(OutputGenerator::RTF);
-    ol.writeAnchor(0,"_details");
+    ol.disableAllBut(OutputGenerator::Html);
+      ol.writeAnchor(0,"_details");
     ol.popGeneratorState();
     ol.startGroupHeader();
-    ol.parseText(theTranslator->trDetailedDescription());
+    ol.parseText(title);
     ol.endGroupHeader();
 
     // repeat brief description
     if (!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF"))
     {
       ol.parseDoc(briefFile(),briefLine(),this,0,briefDescription(),FALSE,FALSE);
-      ol.newParagraph();
+    }
+    // separator between brief and details
+    if (!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF") && 
+        !documentation().isEmpty())
+    {
+      ol.pushGeneratorState();
+        ol.disable(OutputGenerator::Man);
+        ol.disable(OutputGenerator::RTF);
+        ol.newParagraph();
+        ol.enableAll();
+        ol.disableAllBut(OutputGenerator::Man);
+        ol.writeString("\n\n");
+      ol.popGeneratorState();
     }
 
     // write documentation
@@ -136,60 +149,39 @@ void DirDef::writeDetailedDocumentation(OutputList &ol)
   }
 }
 
-void DirDef::writeDocumentation(OutputList &ol)
+void DirDef::writeBriefDescription(OutputList &ol)
 {
-  ol.pushGeneratorState();
-  
-  QCString shortTitle=theTranslator->trDirReference(m_shortName);
-  QCString title=theTranslator->trDirReference(m_dispName);
-  startFile(ol,getOutputFileBase(),name(),title);
-
-  // write navigation path
-  writeNavigationPath(ol);
-
-  startTitle(ol,getOutputFileBase());
-  ol.pushGeneratorState();
-    ol.disableAllBut(OutputGenerator::Html);
-    ol.parseText(shortTitle);
-    ol.enableAll();
-    ol.disable(OutputGenerator::Html);
-    ol.parseText(title);
-  ol.popGeneratorState();
-  endTitle(ol,getOutputFileBase(),title);
-
-  // write brief or details (if DETAILS_AT_TOP)
-  if (Config_getBool("DETAILS_AT_TOP"))
-  {
-    writeDetailedDocumentation(ol);
-    ol.newParagraph();
-  }
-  else if (!briefDescription().isEmpty())
+  if (!briefDescription().isEmpty()) 
   {
     ol.parseDoc(briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE);
-    ol.writeString(" \n");
     ol.pushGeneratorState();
-    ol.disable(OutputGenerator::Latex);
     ol.disable(OutputGenerator::RTF);
-    ol.disable(OutputGenerator::Man);
-    ol.startTextLink(0,"_details");
-    ol.parseText(theTranslator->trMore());
-    ol.endTextLink();
-    ol.enableAll();
-    ol.disableAllBut(OutputGenerator::Man);
+    ol.writeString(" \n");
+    ol.enable(OutputGenerator::RTF);
+
+    if (Config_getBool("REPEAT_BRIEF") ||
+        !documentation().isEmpty()
+       )
+    {
+      ol.disableAllBut(OutputGenerator::Html);
+      ol.startTextLink(0,"_details");
+      ol.parseText(theTranslator->trMore());
+      ol.endTextLink();
+    }
+    ol.popGeneratorState();
+
+    ol.pushGeneratorState();
+    ol.disable(OutputGenerator::RTF);
     ol.newParagraph();
     ol.popGeneratorState();
   }
+  ol.writeSynopsis();
+}
 
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
-  {
-    Doxygen::tagFile << "  <compound kind=\"dir\">" << endl;
-    Doxygen::tagFile << "    <name>" << convertToXML(displayName()) << "</name>" << endl;
-    Doxygen::tagFile << "    <path>" << convertToXML(name()) << "</path>" << endl;
-    Doxygen::tagFile << "    <filename>" << convertToXML(getOutputFileBase()) << Doxygen::htmlFileExtension << "</filename>" << endl;
-  }
-  
+void DirDef::writeDirectoryGraph(OutputList &ol)
+{
   // write graph dependency graph
-  if (Config_getBool("DIRECTORY_GRAPH") && Config_getBool("HAVE_DOT"))
+  if (/*Config_getBool("DIRECTORY_GRAPH") &&*/ Config_getBool("HAVE_DOT"))
   {
     DotDirDeps dirDep(this);
     if (!dirDep.isTrivial())
@@ -203,8 +195,10 @@ void DirDef::writeDocumentation(OutputList &ol)
       ol.enableAll();
     }
   }
+}
 
-  ol.startMemberSections();
+void DirDef::writeSubDirList(OutputList &ol)
+{
   // write subdir list
   if (m_subdirs.count()>0)
   {
@@ -242,7 +236,10 @@ void DirDef::writeDocumentation(OutputList &ol)
 
     ol.endMemberList();
   }
-  
+}
+
+void DirDef::writeFileList(OutputList &ol)
+{
   // write file list
   if (m_fileList->count()>0)
   {
@@ -300,7 +297,117 @@ void DirDef::writeDocumentation(OutputList &ol)
     }
     ol.endMemberList();
   }
+}
+
+void DirDef::startMemberDeclarations(OutputList &ol)
+{
+  ol.startMemberSections();
+}
+
+void DirDef::endMemberDeclarations(OutputList &ol)
+{
   ol.endMemberSections();
+}
+
+void DirDef::writeDocumentation(OutputList &ol)
+{
+  ol.pushGeneratorState();
+  
+  QCString shortTitle=theTranslator->trDirReference(m_shortName);
+  QCString title=theTranslator->trDirReference(m_dispName);
+  startFile(ol,getOutputFileBase(),name(),title,HLI_None,TRUE);
+
+  // write navigation path
+  writeNavigationPath(ol);
+
+  ol.endQuickIndices();
+  ol.startContents();
+
+  startTitle(ol,getOutputFileBase());
+  ol.pushGeneratorState();
+    ol.disableAllBut(OutputGenerator::Html);
+    ol.parseText(shortTitle);
+    ol.enableAll();
+    ol.disable(OutputGenerator::Html);
+    ol.parseText(title);
+  ol.popGeneratorState();
+  endTitle(ol,getOutputFileBase(),title);
+
+  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  {
+    Doxygen::tagFile << "  <compound kind=\"dir\">" << endl;
+    Doxygen::tagFile << "    <name>" << convertToXML(displayName()) << "</name>" << endl;
+    Doxygen::tagFile << "    <path>" << convertToXML(name()) << "</path>" << endl;
+    Doxygen::tagFile << "    <filename>" << convertToXML(getOutputFileBase()) << Doxygen::htmlFileExtension << "</filename>" << endl;
+  }
+  
+  //---------------------------------------- start flexible part -------------------------------
+
+  QListIterator<LayoutDocEntry> eli(
+      LayoutDocManager::instance().docEntries(LayoutDocManager::Directory));
+  LayoutDocEntry *lde;
+  for (eli.toFirst();(lde=eli.current());++eli)
+  {
+    switch (lde->kind())
+    {
+      case LayoutDocEntry::BriefDesc: 
+        writeBriefDescription(ol);
+        break; 
+      case LayoutDocEntry::DirGraph: 
+        writeDirectoryGraph(ol);
+        break; 
+      case LayoutDocEntry::MemberDeclStart: 
+        startMemberDeclarations(ol);
+        break; 
+      case LayoutDocEntry::DirSubDirs: 
+        writeSubDirList(ol);
+        break; 
+      case LayoutDocEntry::DirFiles: 
+        writeFileList(ol);
+        break; 
+      case LayoutDocEntry::MemberDeclEnd: 
+        endMemberDeclarations(ol);
+        break;
+      case LayoutDocEntry::DetailedDesc: 
+        {
+          LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+          writeDetailedDescription(ol,ls->title);
+        }
+        break;
+      case LayoutDocEntry::ClassIncludes:
+      case LayoutDocEntry::ClassInheritanceGraph:
+      case LayoutDocEntry::ClassNestedClasses:
+      case LayoutDocEntry::ClassCollaborationGraph:
+      case LayoutDocEntry::ClassAllMembersLink:
+      case LayoutDocEntry::ClassUsedFiles:
+      case LayoutDocEntry::NamespaceNestedNamespaces:
+      case LayoutDocEntry::NamespaceClasses:
+      case LayoutDocEntry::FileClasses:
+      case LayoutDocEntry::FileNamespaces:
+      case LayoutDocEntry::FileIncludes:
+      case LayoutDocEntry::FileIncludeGraph:
+      case LayoutDocEntry::FileIncludedByGraph: 
+      case LayoutDocEntry::FileSourceLink:
+      case LayoutDocEntry::GroupClasses: 
+      case LayoutDocEntry::GroupNamespaces:
+      case LayoutDocEntry::GroupDirs: 
+      case LayoutDocEntry::GroupNestedGroups: 
+      case LayoutDocEntry::GroupFiles:
+      case LayoutDocEntry::GroupGraph: 
+      case LayoutDocEntry::GroupPageDocs:
+      case LayoutDocEntry::AuthorSection:
+      case LayoutDocEntry::MemberGroups:
+      case LayoutDocEntry::MemberDecl:
+      case LayoutDocEntry::MemberDef:
+      case LayoutDocEntry::MemberDefStart:
+      case LayoutDocEntry::MemberDefEnd:
+        err("Internal inconsistency: member %d should not be part of "
+            "LayoutDocManager::Directory entry list\n",lde->kind());
+        break;
+    }
+  }
+
+  //---------------------------------------- end flexible part -------------------------------
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
   {
@@ -308,14 +415,10 @@ void DirDef::writeDocumentation(OutputList &ol)
     Doxygen::tagFile << "  </compound>" << endl;
   }
 
-
-  if (!Config_getBool("DETAILS_AT_TOP"))
-  {
-    writeDetailedDocumentation(ol);
-  }
-  
   endFile(ol); 
   ol.popGeneratorState();
+
+
 }
 
 #if 0
@@ -555,145 +658,7 @@ DirDef *DirDef::mergeDirectoryInTree(const QCString &path)
 
 void DirDef::writeDepGraph(QTextStream &t)
 {
-    t << "digraph G {\n";
-    if (Config_getBool("DOT_TRANSPARENT"))
-    {
-      t << "  bgcolor=transparent;\n";
-    }
-    t << "  compound=true\n";
-    t << "  node [ fontsize=10, fontname=\"FreeSans.ttf\"];\n";
-    t << "  edge [ labelfontsize=9, labelfontname=\"FreeSans.ttf\"];\n";
-
-    QDict<DirDef> dirsInGraph(257);
-    
-    dirsInGraph.insert(getOutputFileBase(),this);
-    if (parent())
-    {
-      t << "  subgraph cluster" << parent()->getOutputFileBase() << " {\n";
-      t << "    graph [ bgcolor=\"#ddddee\", pencolor=\"black\", label=\"" 
-        << parent()->shortName() 
-        << "\" fontname=\"FreeSans.ttf\", fontsize=10, URL=\"";
-      t << parent()->getOutputFileBase() << Doxygen::htmlFileExtension;
-      t << "\"]\n";
-    }
-    if (isCluster())
-    {
-      t << "  subgraph cluster" << getOutputFileBase() << " {\n";
-      t << "    graph [ bgcolor=\"#eeeeff\", pencolor=\"black\", label=\"\""
-        << " URL=\"" << getOutputFileBase() << Doxygen::htmlFileExtension 
-        << "\"];\n";
-      t << "    " << getOutputFileBase() << " [shape=plaintext label=\"" 
-        << shortName() << "\"];\n";
-
-      // add nodes for sub directories
-      QListIterator<DirDef> sdi(m_subdirs);
-      DirDef *sdir;
-      for (sdi.toFirst();(sdir=sdi.current());++sdi)
-      {
-        t << "    " << sdir->getOutputFileBase() << " [shape=box label=\"" 
-          << sdir->shortName() << "\"";
-        if (sdir->isCluster())
-        {
-          t << " color=\"red\"";
-        }
-        else
-        {
-          t << " color=\"black\"";
-        }
-        t << " fillcolor=\"white\" style=\"filled\"";
-        t << " URL=\"" << sdir->getOutputFileBase() 
-          << Doxygen::htmlFileExtension << "\"";
-        t << "];\n";
-        dirsInGraph.insert(sdir->getOutputFileBase(),sdir);
-      }
-      t << "  }\n";
-    }
-    else
-    {
-      t << "  " << getOutputFileBase() << " [shape=box, label=\"" 
-        << shortName() << "\", style=\"filled\", fillcolor=\"#eeeeff\","
-        << " pencolor=\"black\", URL=\"" << getOutputFileBase() 
-        << Doxygen::htmlFileExtension << "\"];\n";
-    }
-    if (parent())
-    {
-      t << "  }\n";
-    }
-
-    // add nodes for other used directories
-    QDictIterator<UsedDir> udi(*m_usedDirs);
-    UsedDir *udir;
-    //printf("*** For dir %s\n",shortName().data());
-    for (udi.toFirst();(udir=udi.current());++udi) 
-      // for each used dir (=directly used or a parent of a directly used dir)
-    {
-      const DirDef *usedDir=udir->dir();
-      DirDef *dir=this;
-      while (dir)
-      {
-        //printf("*** check relation %s->%s same_parent=%d !%s->isParentOf(%s)=%d\n",
-        //    dir->shortName().data(),usedDir->shortName().data(),
-        //    dir->parent()==usedDir->parent(),
-        //    usedDir->shortName().data(),
-        //    shortName().data(),
-        //    !usedDir->isParentOf(this)
-        //    );
-        if (dir!=usedDir && dir->parent()==usedDir->parent() && !usedDir->isParentOf(this))
-          // include if both have the same parent (or no parent)
-        {
-          t << "  " << usedDir->getOutputFileBase() << " [shape=box label=\"" 
-            << usedDir->shortName() << "\"";
-          if (usedDir->isCluster())
-          {
-            if (!Config_getBool("DOT_TRANSPARENT"))
-            {
-              t << " fillcolor=\"white\" style=\"filled\"";
-            }
-            t << " color=\"red\"";
-          }
-          t << " URL=\"" << usedDir->getOutputFileBase() 
-            << Doxygen::htmlFileExtension << "\"];\n";
-          dirsInGraph.insert(usedDir->getOutputFileBase(),usedDir);
-          break;
-        }
-        dir=dir->parent();
-      }
-    }
-
-    // add relations between all selected directories
-    DirDef *dir;
-    QDictIterator<DirDef> di(dirsInGraph);
-    for (di.toFirst();(dir=di.current());++di) // foreach dir in the graph
-    {
-      QDictIterator<UsedDir> udi(*dir->usedDirs());
-      UsedDir *udir;
-      for (udi.toFirst();(udir=udi.current());++udi) // foreach used dir
-      {
-        const DirDef *usedDir=udir->dir();
-        if ((dir!=this || !udir->inherited()) &&     // only show direct dependendies for this dir
-            (usedDir!=this || !udir->inherited()) && // only show direct dependendies for this dir
-            !usedDir->isParentOf(dir) &&             // don't point to own parent
-            dirsInGraph.find(usedDir->getOutputFileBase())) // only point to nodes that are in the graph
-        {
-          QCString relationName;
-          relationName.sprintf("dir_%06d_%06d",dir->m_dirCount,usedDir->m_dirCount);
-          if (Doxygen::dirRelations.find(relationName)==0)
-          {
-            // new relation
-            Doxygen::dirRelations.append(relationName,
-                new DirRelation(relationName,dir,udir));
-          }
-          int nrefs = udir->filePairs().count();
-          t << "  " << dir->getOutputFileBase() << "->" 
-                    << usedDir->getOutputFileBase();
-          t << " [headlabel=\"" << nrefs << "\", labeldistance=1.5";
-          t << " headhref=\"" << relationName << Doxygen::htmlFileExtension 
-            << "\"];\n";
-        }
-      }
-    }
-
-    t << "}\n";
+    writeDotDirDepGraph(t,this);
 }
 
 //----------------------------------------------------------------------
@@ -908,7 +873,7 @@ void writeDirDependencyGraph(const char *dirName)
       
       //QCString dotArgs(4096);
       //dotArgs.sprintf("%s -Tgif -o %s",path.data(),outFile.data());
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs,FALSE)!=0)
+      //if (portable_system(Config_getString("DOT_PATH")+"dot",dotArgs,FALSE)!=0)
       //{
       //  err("Problems running dot. Check your installation!\n");
       //}
