@@ -57,7 +57,6 @@ class MemberDef : public Definition
       Typedef, 
       Enumeration, 
       EnumValue,
-      Prototype,
       Signal,
       Slot,
       Friend,
@@ -69,7 +68,7 @@ class MemberDef : public Definition
     MemberDef(const char *defFileName,int defLine,
               const char *type,const char *name,const char *args,
               const char *excp,Protection prot,Specifier virt,bool stat,
-              bool related,MemberType t,const ArgumentList *tal,
+              Relationship related,MemberType t,const ArgumentList *tal,
               const ArgumentList *al);
    ~MemberDef(); 
     DefType definitionType() const        { return TypeMember; }
@@ -133,6 +132,7 @@ class MemberDef : public Definition
     bool isProperty() const;
     bool isEvent() const;
     bool isRelated() const;
+    bool isForeign() const;
     bool isStatic() const;
     bool isInline() const;
     bool isExplicit() const;
@@ -172,7 +172,7 @@ class MemberDef : public Definition
     bool isLinkableInProject() const;
     bool isLinkable() const;
     bool hasDocumentation() const;  // overrides hasDocumentation in definition.h
-    bool hasUserDocumentation() const; // overrides hasUserDocumentation
+    //bool hasUserDocumentation() const; // overrides hasUserDocumentation
     bool isBriefSectionVisible() const;
     bool isDetailedSectionVisible(bool inGroup,bool inFile) const;
     bool isDetailedSectionLinkable() const;
@@ -182,9 +182,9 @@ class MemberDef : public Definition
     MemberDef *reimplements() const;
     LockingPtr<MemberList> reimplementedBy() const;
 
-    int inbodyLine() const;
-    QCString inbodyFile() const;
-    const QCString &inbodyDocumentation() const;
+    //int inbodyLine() const;
+    //QCString inbodyFile() const;
+    //const QCString &inbodyDocumentation() const;
 
     ClassDef *relatedAlso() const;
 
@@ -257,6 +257,7 @@ class MemberDef : public Definition
     void setTemplateSpecialization(bool b);
     
     void makeRelated();
+    void makeForeign();
     void setHasDocumentedParams(bool b);
     void setHasDocumentedReturnType(bool b);
     void setInheritsDocsFrom(MemberDef *md);
@@ -268,7 +269,7 @@ class MemberDef : public Definition
     void insertReimplementedBy(MemberDef *md);
 
     // in-body documentation
-    void setInbodyDocumentation(const char *docs,const char *file,int line);
+    //void setInbodyDocumentation(const char *docs,const char *file,int line);
 
     void setRelatedAlso(ClassDef *cd);
 
