@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -79,7 +79,7 @@
 #ifndef TRANSLATOR_DK_H
 #define TRANSLATOR_DK_H
 
-class TranslatorDanish : public Translator
+class TranslatorDanish : public TranslatorAdapter_1_5_4
 {
   public:
 
@@ -109,7 +109,6 @@ class TranslatorDanish : public Translator
     {
       return
 	"\\usepackage[danish]{babel}\n"
-	"\\usepackage[latin1]{inputenc}\n"
 	"\\usepackage[T1]{fontenc}\n";
     }
 
@@ -1003,7 +1002,7 @@ class TranslatorDanish : public Translator
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
         "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
