@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -77,14 +77,14 @@ class TranslatorCroatian : public Translator
         /*! to avoid macro redefinition from translator_cz.h */
         inline QCString decode(const QCString& sInput)
         { 
-          if (Config_getBool("USE_WINDOWS_ENCODING"))
-          {
-            return ISO88592ToWin1250(sInput);
-          }
-          else
-          {
+          //if (Config_getBool("USE_WINDOWS_ENCODING"))
+          //{
+          //  return ISO88592ToWin1250(sInput);
+          //}
+          //else
+          //{
             return sInput;
-          }
+          //}
         }
   
   public:
@@ -92,14 +92,14 @@ class TranslatorCroatian : public Translator
     { return "croatian"; }
     QCString idLanguageCharset()
     {
-      if (Config_getBool("USE_WINDOWS_ENCODING"))
-      {
-        return "windows-1250"; 
-      }
-      else
-      {
+      //if (Config_getBool("USE_WINDOWS_ENCODING"))
+      //{
+      //  return "windows-1250"; 
+      //}
+      //else
+      //{
         return "iso-8859-2";
-      }
+      //}
     }
     QCString latexLanguageSupportCommand()
     { return "\\usepackage[croatian]{babel}\n"; }
@@ -371,8 +371,8 @@ class TranslatorCroatian : public Translator
         case ClassDef::Struct: result+=" strukture "; break;
         case ClassDef::Union:  result+=" unije "; break;
         case ClassDef::Interface:  result+=" suelja (interface) "; break;
-        case ClassDef::Protocol:   result+=" protocol "; break; // translate me!
-        case ClassDef::Category:   result+=" category "; break; // translate me!
+        case ClassDef::Protocol:   result+=" protokola "; break; 
+        case ClassDef::Category:   result+=" kategorije "; break; 
         case ClassDef::Exception:  result+=" iznimke (exception) "; break;
       }
           result += clName;
@@ -411,11 +411,11 @@ class TranslatorCroatian : public Translator
     QCString trStaticProtectedMembers()
     { return decode("Static protected lanovi"); }
     QCString trPrivateMembers()
-    { return decode("Private lanovi"); }
+    { return decode("Privatni lanovi"); }
     QCString trPrivateSlots()
-    { return decode("Private slotovi"); }
+    { return decode("Privatni slotovi"); }
     QCString trStaticPrivateMembers()
-    { return decode("Static private lanovi"); }
+    { return decode("Statini privatni lanovi"); }
     // end of member sections 
     
     QCString trWriteList(int numEntries)
@@ -514,15 +514,15 @@ class TranslatorCroatian : public Translator
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result="Dokumentacija ove ";
+      QCString result="Dokumentacija ";
       switch(compType)
       {
         case ClassDef::Class:      result+="klase"; break;
         case ClassDef::Struct:     result+="strukture"; break;
         case ClassDef::Union:      result+="unije"; break;
         case ClassDef::Interface:  result+="suelja (interface)"; break;
-        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-        case ClassDef::Category:   result+="category"; break; // translate me!
+        case ClassDef::Protocol:   result+="protokola"; break; 
+        case ClassDef::Category:   result+="kategorije"; break; 
         case ClassDef::Exception:  result+="iznimke (exception)"; break;
       }
       result+=" je generirana iz " + trFile(FALSE, single) + ": ";
@@ -757,6 +757,8 @@ class TranslatorCroatian : public Translator
         "class Undocumented { };\n\n"
         "/*! Klasa koja je naslijeena public  */\n"
         "class PublicBase : public Truncated { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Klasa koje je naslijeena protected */\n"
         "class ProtectedBase { };\n\n"
         "/*! Klasa koje je naslijeena private */\n"
@@ -767,7 +769,8 @@ class TranslatorCroatian : public Translator
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
@@ -1271,6 +1274,202 @@ class TranslatorCroatian : public Translator
      */
     virtual QCString trEnumerationValueDocumentation()
     { return "Dokumentacija enumeracija"; }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.5.4 (mainly for Fortran)
+//////////////////////////////////////////////////////////////////////////
+
+    /*! header that is put before the list of member subprograms (Fortran). */
+    virtual QCString trMemberFunctionDocumentationFortran()
+    { return "Dokumentacija member funkcija/subrutina"; }
+
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    virtual QCString trCompoundListFortran()
+    { return "Lista tipova podataka"; }
+
+    /*! This is put above each page as a link to all members of compounds (Fortran). */
+    virtual QCString trCompoundMembersFortran()
+    { return "Polja"; }
+
+    /*! This is an introduction to the annotated compound list (Fortran). */
+    virtual QCString trCompoundListDescriptionFortran()
+    { return "Tipovi podataka s kratkim opisom:"; }
+
+    /*! This is an introduction to the page with all data types (Fortran). */
+    virtual QCString trCompoundMembersDescriptionFortran(bool extractAll)
+    {
+      QCString result="Lista svih ";
+      if (!extractAll)
+      {
+        result+="dokumentiranih ";
+      }
+      result+="polja";
+      result+=" s linkovima na ";
+      if (!extractAll) 
+      {
+        result+="dokumentaciju struktura podataka za svako polje";
+      }
+      else 
+      {
+        result+="strukture kojima pripadaju:";
+      }
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+    * annotated compound index (Fortran).
+    */
+    virtual QCString trCompoundIndexFortran()
+    { return "Kazalo data tipova"; }
+
+    /*! This is used in LaTeX as the title of the chapter containing
+    *  the documentation of all data types (Fortran).
+    */
+    virtual QCString trTypeDocumentation()
+    { return "Dokumentacija tipova podataka"; }
+
+    /*! This is used in the documentation of a file as a header before the 
+    *  list of (global) subprograms (Fortran).
+    */
+    virtual QCString trSubprograms()
+    { return "Funkcije/Subrutine"; }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+    *  of documentation blocks for subprograms (Fortran)
+    */
+    virtual QCString trSubprogramDocumentation()
+    { return "Documentacija funkcija/subrutina"; }
+
+    /*! This is used in the documentation of a file/namespace/group before 
+    *  the list of links to documented compounds (Fortran)
+    */
+    virtual QCString trDataTypes()
+    { return "Tipovi podataka"; }
+
+    /*! used as the title of page containing all the index of all modules (Fortran). */
+    virtual QCString trModulesList()
+    { return "Popis modula"; }
+
+    /*! used as an introduction to the modules list (Fortran) */
+    virtual QCString trModulesListDescription(bool extractAll)
+    {
+      QCString result="Lista svih ";
+      if (!extractAll) result+="dokumentiranih ";
+      result+="modula s kratkim opisom:";
+      return result;
+    }
+
+    /*! used as the title of the HTML page of a module/type (Fortran) */
+    virtual QCString trCompoundReferenceFortran(const char *clName,
+      ClassDef::CompoundType compType,
+      bool isTemplate)
+    {
+      QCString result=(QCString)clName;
+      switch(compType)
+      {
+      case ClassDef::Class:      result+=" Modul"; break;
+      case ClassDef::Struct:     result+=" Tip"; break;
+      case ClassDef::Union:      result+=" Unija"; break;
+      case ClassDef::Interface:  result+=" Suelje"; break;
+      case ClassDef::Protocol:   result+=" Protokol"; break;
+      case ClassDef::Category:   result+=" Kategorija"; break;
+      case ClassDef::Exception:  result+=" Iznimka"; break;
+      }
+      if (isTemplate) result+=" Predloak";
+      result+=" Referenca";
+      return result;
+    }
+    /*! used as the title of the HTML page of a module (Fortran) */
+    virtual QCString trModuleReference(const char *namespaceName)
+    {
+      QCString result=namespaceName;
+      result+=" - Sadraj modula";        
+      return result;
+    }
+
+    /*! This is put above each page as a link to all members of modules. (Fortran) */
+    virtual QCString trModulesMembers()
+    { return "lanovi modula"; }
+
+    /*! This is an introduction to the page with all modules members (Fortran) */
+    virtual QCString trModulesMemberDescription(bool extractAll)
+    { 
+      QCString result="Lista svih ";
+      if (!extractAll) result+="dokumentiranih ";
+      result+="lanova modula s linkovima na ";
+      if (extractAll) 
+      {
+        result+="dokumentaciju modula za svaki lan:";
+      }
+      else 
+      {
+        result+="modul kojem pripadaju:";
+      }
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+    *  index of all modules (Fortran).
+    */
+    virtual QCString trModulesIndex()
+    { return "Kazalo modula"; }
+
+    /*! This is used for translation of the word that will possibly
+    *  be followed by a single name or by a list of names 
+    *  of the category.
+    */
+    virtual QCString trModule(bool first_capital, bool singular)
+    {       
+      QCString result((first_capital ? "Modul" : "modul"));
+      if (!singular)  result+="i";
+      return result; 
+    }
+    /*! This is put at the bottom of a module documentation page and is
+    *  followed by a list of files that were used to generate the page.
+    */
+    virtual QCString trGeneratedFromFilesFortran(ClassDef::CompoundType compType,
+      bool)
+    { // here s is one of " Module", " Struct" or " Union"
+      // single is true implies a single file
+      QCString result=(QCString)"Dokumentacija ovog ";
+      switch(compType)
+      {
+      case ClassDef::Class:      result+="modula"; break;
+      case ClassDef::Struct:     result+="tipa"; break;
+      case ClassDef::Union:      result+="unije"; break;
+      case ClassDef::Interface:  result+="suelja"; break;
+      case ClassDef::Protocol:   result+="protokola"; break;
+      case ClassDef::Category:   result+="kategorije"; break;
+      case ClassDef::Exception:  result+="iznimke"; break;
+      }
+      result+=" je generirana iz :";
+      return result;
+    }
+    /*! This is used for translation of the word that will possibly
+    *  be followed by a single name or by a list of names 
+    *  of the category.
+    */
+    virtual QCString trType(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Tip" : "tip"));
+      if (!singular)  result+="ovi";
+      return result; 
+    }
+    /*! This is used for translation of the word that will possibly
+    *  be followed by a single name or by a list of names 
+    *  of the category.
+    */
+    virtual QCString trSubprogram(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Subprogram" : "subprogram"));
+      if (!singular)  result+="i";
+      return result; 
+    }
+
+    /*! C# Type Contraint list */
+    virtual QCString trTypeConstraints()
+    {
+      return "Ogranienja za tip podataka";
+    }
 };
 
 #endif
